
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

class V1::InstitutionsController < ApplicationController
  include ::DeletedObjectsController
  include ::Paginator


  before_action :set_institution, only: [:show, :update, :destroy, :users]
  before_action :authenticate_user!, only: [:create, :update, :destroy]
  before_action :authorize!, only: [:update, :destroy]

  # GET v1/institutions
  # GET v1/institutions.json
  def index
    institutions = paginate Institution
    render json: institutions
  end

  # GET v1/institutions/1
  # GET v1/institutions/1.json
  def show
    render json: @institution
  end

  # POST v1/institutions
  # POST v1/institutions.json
  def create
    institution = Institution.new(institution_params)
    authorize institution

    if institution.save
      render json: institution, status: :created
    else
      render json: institution.errors, status: :unprocessable_entity
    end
  end

  # PUT/PATCH /v1/institutions/1
  # PUT/PATCH /v1/institutions/1.json
  def update
    if @institution.update(institution_params)
      render json: @institution, status: :ok
    else
      render json: @institution.errors, status: :unprocessable_entity
    end
  end

  # DELETE v1/institutions/1
  # DELETE v1/institutions/1.json
  def destroy
    @institution.destroy
    response = { 'status': 'deleted' }
    render status: :ok, json: response
  end

  def users
    @users = @institution.users
    render json: @users, status: :ok
  end

  private

  def deleted_resource
    Institution
  end

  def set_institution
    @institution = Institution.find(params[:id])
  end

  def institution_params
    params.require(:institution).permit(:name, :description, :address, :city, :country)
  end

  def authorize!
    authorize @institution
  end

end
