
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

class V1::RatingsController < ApplicationController
  include ::DeletedObjectsController
  include ::Paginator

  before_action :set_rating, only: [:show, :update, :destroy]
  before_action :authenticate_user!, only: [:create, :update, :destroy]
  before_action :authorize!, only: [:update, :destroy]

  # GET v1/ratings
  # GET v1/ratings.json
  def index
    ratings = paginate Rating
    render json: ratings
  end

  # GET v1/ratings/1
  # GET v1/ratings/1.json
  def show
    render json: @rating
  end

  # POST v1/ratings
  # POST v1/ratings.json
  def create
    rating = Rating.new(rating_params)
    authorize rating

    if rating.save
      render json: rating, status: :created
    else
      render json: rating.errors, status: :unprocessable_entity
    end
  end

  # PUT/PATCH /v1/ratings/1
  # PUT/PATCH /v1/ratings/1.json
  def update
    if @rating.update(rating_params)
      render json: @rating, status: :ok
    else
      render json: @rating.errors, status: :unprocessable_entity
    end
  end

  # DELETE v1/ratings/1
  # DELETE v1/ratings/1.json
  def destroy
    @rating.destroy
    response = { 'status': 'deleted' }
    render nothing: true, status: :ok, json: response
  end

  private

  def deleted_resource
    Rating
  end

  def set_rating
    @rating = Rating.find(params[:id])
  end

  def rating_params
    params.require(:rating).permit(:name, :description)
  end

  def authorize!
    authorize @rating
  end
end
